@@ -33,7 +33,7 @@
 #include "indent.h"
 #include "globs.h"
 
-RCSTAG_CC ("$Id: lexi.c,v 1.20 1999/09/03 11:33:40 carlo Exp $");
+RCSTAG_CC ("$Id: lexi.c,v 1.26 2000/11/17 03:01:04 carlo Exp $");
 
 /* Stuff that needs to be shared with the rest of indent. Documented in
    indent.h.  */
@@ -96,99 +96,103 @@ char chartype[] = {		/* this is used to facilitate the decision of
   0, 0, 0, 0, 0, 0, 0, 0,
   0, 0, 0, 0, 0, 0, 0, 0,
 
-#else /* CHARSET_EBCDIC */
+#else				/* CHARSET_EBCDIC */
 
 /*
- * The following table was generated by this program from
- * the ASCII version of the chartype[] array:
+ * The following table was generated by the program given at the end
  */
-#if 0
-    int main()
-    {
-	const int GAP = 8;
-	int i, j;
 
-	for(i = 0; i < 256; i += GAP) {
-	    printf("  ");
-	    for(j = 0; j < GAP; ++j) {
-		printf("%d, ", chartype[os_toascii[i + j]]);
-	    }
-	    printf(" /*|");
-	    for(j = 0; j < GAP; ++j) {
-		printf("%c", isprint(i + j) ? (i + j) : '.');
-	    }
-	    printf("|*/\n");
-	}
-	return 0;
-    }
-#endif
+  0, 0, 0, 0, 0, 0, 0, 0,	/*|........| */
+  0, 0, 0, 0, 0, 0, 0, 0,	/*|........| */
+  0, 0, 0, 0, 0, 0, 0, 0,	/*|........| */
+  0, 0, 0, 0, 0, 0, 0, 0,	/*|........| */
+  0, 0, 0, 0, 0, 0, 0, 0,	/*|........| */
+  0, 0, 0, 0, 0, 0, 0, 0,	/*|........| */
+  0, 0, 0, 0, 0, 0, 0, 0,	/*|........| */
+  0, 0, 0, 0, 0, 0, 0, 0,	/*|........| */
+  0, 0, 0, 0, 0, 0, 0, 0,	/*| .......| */
+  0, 0, 0, 0, 3, 0, 3, 3,	/*|..`.<(+|| */
+  3, 0, 0, 0, 0, 0, 0, 0,	/*|&.......| */
+  0, 0, 3, 1, 3, 0, 0, 0,	/*|..!$*);.| */
+  3, 3, 0, 0, 0, 0, 0, 0,	/*|-/......| */
+  0, 0, 3, 0, 3, 1, 3, 3,	/*|..^,%_>?| */
+  0, 0, 0, 0, 0, 0, 0, 0,	/*|........| */
+  0, 0, 0, 0, 0, 0, 3, 0,	/*|..:#@'="| */
+  0, 1, 1, 1, 1, 1, 1, 1,	/*|.abcdefg| */
+  1, 1, 0, 0, 0, 0, 0, 0,	/*|hi......| */
+  0, 1, 1, 1, 1, 1, 1, 1,	/*|.jklmnop| */
+  1, 1, 0, 0, 0, 0, 0, 0,	/*|qr......| */
+  0, 0, 1, 1, 1, 1, 1, 1,	/*|..stuvwx| */
+  1, 1, 0, 0, 0, 0, 0, 0,	/*|yz......| */
+  0, 0, 0, 0, 0, 0, 0, 0,	/*|........| */
+  0, 0, 0, 0, 0, 0, 0, 0,	/*|...[\]..| */
+  0, 1, 1, 1, 1, 1, 1, 1,	/*|.ABCDEFG| */
+  1, 1, 0, 0, 0, 0, 0, 0,	/*|HI......| */
+  0, 1, 1, 1, 1, 1, 1, 1,	/*|.JKLMNOP| */
+  1, 1, 0, 0, 0, 0, 0, 0,	/*|QR......| */
+  0, 0, 1, 1, 1, 1, 1, 1,	/*|..STUVWX| */
+  1, 1, 0, 0, 0, 0, 0, 0,	/*|YZ......| */
+  1, 1, 1, 1, 1, 1, 1, 1,	/*|01234567| */
+  1, 1, 0, 0, 0, 0, 0, 3,	/*|89.{.}.~| */
+#endif				/* CHARSET_EBCDIC */
+};
+
 /*
- * where the unsigned char os_toascii[] array can be found in the source
+ * The table above was generated by the following program from
+ * the ASCII version of the chartype[] array above, where the
+ * unsigned char os_toascii[] array can be found in the source
  * for the Apache Web Server version 1.3.x, in the directories...
  *  src/os/bs2000/ebcdic.c    for the SIEMENS BS2000 mainframes,
  *  src/os/tpf/ebcdic.c       for the IBM TPF server line.
  * The following table was created for BS2000 EBCDIC character set,
  * but the few non-zero places should be compatible with IBM's EBCDIC.
  */
+#if 0
+int
+main ()
+{
+  const int GAP = 8;
+  int i, j;
 
-  0, 0, 0, 0, 0, 0, 0, 0,  /*|........|*/
-  0, 0, 0, 0, 0, 0, 0, 0,  /*|........|*/
-  0, 0, 0, 0, 0, 0, 0, 0,  /*|........|*/
-  0, 0, 0, 0, 0, 0, 0, 0,  /*|........|*/
-  0, 0, 0, 0, 0, 0, 0, 0,  /*|........|*/
-  0, 0, 0, 0, 0, 0, 0, 0,  /*|........|*/
-  0, 0, 0, 0, 0, 0, 0, 0,  /*|........|*/
-  0, 0, 0, 0, 0, 0, 0, 0,  /*|........|*/
-  0, 0, 0, 0, 0, 0, 0, 0,  /*| .......|*/
-  0, 0, 0, 0, 3, 0, 3, 3,  /*|..`.<(+||*/
-  3, 0, 0, 0, 0, 0, 0, 0,  /*|&.......|*/
-  0, 0, 3, 1, 3, 0, 0, 0,  /*|..!$*);.|*/
-  3, 3, 0, 0, 0, 0, 0, 0,  /*|-/......|*/
-  0, 0, 3, 0, 3, 1, 3, 3,  /*|..^,%_>?|*/
-  0, 0, 0, 0, 0, 0, 0, 0,  /*|........|*/
-  0, 0, 0, 0, 0, 0, 3, 0,  /*|..:#@'="|*/
-  0, 1, 1, 1, 1, 1, 1, 1,  /*|.abcdefg|*/
-  1, 1, 0, 0, 0, 0, 0, 0,  /*|hi......|*/
-  0, 1, 1, 1, 1, 1, 1, 1,  /*|.jklmnop|*/
-  1, 1, 0, 0, 0, 0, 0, 0,  /*|qr......|*/
-  0, 0, 1, 1, 1, 1, 1, 1,  /*|..stuvwx|*/
-  1, 1, 0, 0, 0, 0, 0, 0,  /*|yz......|*/
-  0, 0, 0, 0, 0, 0, 0, 0,  /*|........|*/
-  0, 0, 0, 0, 0, 0, 0, 0,  /*|...[\]..|*/
-  0, 1, 1, 1, 1, 1, 1, 1,  /*|.ABCDEFG|*/
-  1, 1, 0, 0, 0, 0, 0, 0,  /*|HI......|*/
-  0, 1, 1, 1, 1, 1, 1, 1,  /*|.JKLMNOP|*/
-  1, 1, 0, 0, 0, 0, 0, 0,  /*|QR......|*/
-  0, 0, 1, 1, 1, 1, 1, 1,  /*|..STUVWX|*/
-  1, 1, 0, 0, 0, 0, 0, 0,  /*|YZ......|*/
-  1, 1, 1, 1, 1, 1, 1, 1,  /*|01234567|*/
-  1, 1, 0, 0, 0, 0, 0, 3,  /*|89.{.}.~|*/
-#endif /* CHARSET_EBCDIC */
-};
+  for (i = 0; i < 256; i += GAP)
+    {
+      printf ("  ");
+      for (j = 0; j < GAP; ++j)
+	{
+	  printf ("%d, ", chartype[os_toascii[i + j]]);
+	}
+      printf (" /*|");
+      for (j = 0; j < GAP; ++j)
+	{
+	  printf ("%c", isprint (i + j) ? (i + j) : '.');
+	}
+      printf ("|*/\n");
+    }
+  return 0;
+}
+#endif
 
 /* Include code generated by gperf */
 #ifdef PROTOTYPES
 #ifdef __GNUC__
 __inline
 #endif
-struct templ *is_reserved PARAMS ((register const char *str,
-				   register unsigned int len));
+struct templ *is_reserved PARAMS ((register const char *str, register unsigned int len));
 #endif
 #include "gperf.c"
 
 /* Include code generated by gperf for C++ keyword set */
-#undef MIN_HASH_VALUE /* remove old defs */
+#undef MIN_HASH_VALUE		/* remove old defs */
 #undef MAX_HASH_VALUE
 #undef TOTAL_KEYWORDS
-#undef MIN_WORD_LENGTH 
-#undef MAX_WORD_LENGTH 
+#undef MIN_WORD_LENGTH
+#undef MAX_WORD_LENGTH
 
 #ifdef PROTOTYPES
 #ifdef __GNUC__
 __inline
 #endif
-struct templ *is_reserved_cc PARAMS ((register const char *str,
-				      register unsigned int len));
+struct templ *is_reserved_cc PARAMS ((register const char *str, register unsigned int len));
 #endif
 #include "gperf-cc.c"
 
@@ -205,6 +209,7 @@ lexi ()
   char qchar;			/* the delimiter character for a string */
 
   static int count;		/* debugging counter */
+
   count++;
 
   unary_delim = false;
@@ -233,8 +238,7 @@ lexi ()
   token = buf_ptr;
 
   /* Scan an alphanumeric token */
-  if ((!(buf_ptr[0] == 'L' && (buf_ptr[1] == '"' || buf_ptr[1] == '\''))
-       && chartype[0xff & (int) *buf_ptr] == alphanum)
+  if ((!(buf_ptr[0] == 'L' && (buf_ptr[1] == '"' || buf_ptr[1] == '\'')) && chartype[0xff & (int) *buf_ptr] == alphanum)
       || (buf_ptr[0] == '.' && isdigit (buf_ptr[1])))
     {
       /* we have a character or number */
@@ -243,6 +247,7 @@ lexi ()
       if (isdigit (*buf_ptr) || (buf_ptr[0] == '.' && isdigit (buf_ptr[1])))
 	{
 	  int seendot = 0, seenexp = 0;
+
 	  if (*buf_ptr == '0' && (buf_ptr[1] == 'x' || buf_ptr[1] == 'X'))
 	    {
 	      buf_ptr += 2;
@@ -277,16 +282,11 @@ lexi ()
 		  }
 	      }
 
-	  if (*buf_ptr == 'F' || *buf_ptr == 'f'
-	      || *buf_ptr == 'i' || *buf_ptr == 'j')
+	  if (*buf_ptr == 'F' || *buf_ptr == 'f' || *buf_ptr == 'i' || *buf_ptr == 'j')
 	    buf_ptr++;
 	  else
 	    {
-	      if (*buf_ptr == 'U' || *buf_ptr == 'u')
-		buf_ptr++;
-	      if (*buf_ptr == 'L' || *buf_ptr == 'l')
-		buf_ptr++;
-	      if (*buf_ptr == 'L' || *buf_ptr == 'l')
+	      while (*buf_ptr == 'U' || *buf_ptr == 'u' || *buf_ptr == 'L' || *buf_ptr == 'l')
 		buf_ptr++;
 	    }
 	}
@@ -339,8 +339,7 @@ lexi ()
 
       if (!p && user_specials != 0)
 	{
-	  for (p = &user_specials[0];
-	       p < &user_specials[0] + user_specials_idx; p++)
+	  for (p = &user_specials[0]; p < &user_specials[0] + user_specials_idx; p++)
 	    {
 	      char *q = token;
 	      char *r = p->rwd;
@@ -397,13 +396,10 @@ lexi ()
 	      l_enum = true;	/* reset on '(' ')' '{' '}' or ';' */
 	      /* fall through */
 	    case rw_struct_like:	/* a "struct" */
-	      if (parser_state_tos->p_l_follow
-		  && !(parser_state_tos->noncast_mask
-		       & 1 << parser_state_tos->p_l_follow))
+	      if (parser_state_tos->p_l_follow && !(parser_state_tos->noncast_mask & 1 << parser_state_tos->p_l_follow))
 		/* inside parens: cast */
 		{
-		  parser_state_tos->cast_mask |=
-		    1 << parser_state_tos->p_l_follow;
+		  parser_state_tos->cast_mask |= 1 << parser_state_tos->p_l_follow;
 		  break;
 		}
 	      l_struct = true;
@@ -411,13 +407,10 @@ lexi ()
 	      /* Next time around, we will want to know that we have had a
 	         'struct' */
 	    case rw_decl:	/* one of the declaration keywords */
-	      if (parser_state_tos->p_l_follow
-		  && !(parser_state_tos->noncast_mask
-		       & 1 << parser_state_tos->p_l_follow))
+	      if (parser_state_tos->p_l_follow && !(parser_state_tos->noncast_mask & 1 << parser_state_tos->p_l_follow))
 		/* inside parens: cast */
 		{
-		  parser_state_tos->cast_mask |=
-		    1 << parser_state_tos->p_l_follow;
+		  parser_state_tos->cast_mask |= 1 << parser_state_tos->p_l_follow;
 		  break;
 		}
 	      last_code = decl;
@@ -454,9 +447,7 @@ lexi ()
 	    return overloaded;
 	  return value;
 	}			/* end of if (found_it) */
-      else if (*buf_ptr == '('
-	       && parser_state_tos->tos <= 1
-	       && parser_state_tos->ind_level == 0
+      else if (*buf_ptr == '(' && parser_state_tos->tos <= 1 && parser_state_tos->ind_level == 0
 	       && parser_state_tos->paren_depth == 0)
 	{
 	  /* We have found something which might be the name in a function
@@ -464,9 +455,16 @@ lexi ()
 	  char *tp;
 	  int paren_count = 1;
 
+	  /* If the return type of this function definition was not defined
+	     with a -T commandline option, then the output of indent would
+	     alternate on subsequent calls.  In order to avoid that we try
+	     to detect that case here and make a minimal change to cause
+	     the correct behaviour. */
+	  if (parser_state_tos->last_token == ident && parser_state_tos->last_saw_nl)
+	    parser_state_tos->in_decl = 1;
+
 	  /* Skip to the matching ')'.  */
-	  for (tp = buf_ptr + 1;
-	       paren_count > 0 && tp < in_prog + in_prog_size; tp++)
+	  for (tp = buf_ptr + 1; paren_count > 0 && tp < in_prog + in_prog_size; tp++)
 	    {
 	      if (*tp == '(')
 		paren_count++;
@@ -486,8 +484,7 @@ lexi ()
 	      while (isspace (*tp))
 		tp++;
 
-	      if (*tp == '_' && in_prog + in_prog_size - tp >= 13 &&
-		  !strncmp (tp, "__attribute__", 13))
+	      if (*tp == '_' && in_prog + in_prog_size - tp >= 13 && !strncmp (tp, "__attribute__", 13))
 		{
 		  /* Found an __attribute__ after a function declaration */
 		  goto not_proc;	/* Must be a declaration */
@@ -506,10 +503,8 @@ lexi ()
 
 	not_proc:;
 	}
-      else if (*buf_ptr == ':' && *(buf_ptr + 1) == ':'
-	       && parser_state_tos->tos <= 1
-	       && parser_state_tos->ind_level == 0
-	       && parser_state_tos->paren_depth == 0)
+      else if (*buf_ptr == ':' && *(buf_ptr + 1) == ':' && parser_state_tos->tos <= 1
+	       && parser_state_tos->ind_level == 0 && parser_state_tos->paren_depth == 0)
 	{
 	  parser_state_tos->classname = token;
 	  parser_state_tos->classname_end = token_end;
@@ -517,16 +512,11 @@ lexi ()
       /* The following hack attempts to guess whether or not the
          current token is in fact a declaration keyword -- one that
          has been typedef'd */
-      else if (((*buf_ptr == '*' && buf_ptr[1] != '=')
-		|| isalpha (*buf_ptr) || *buf_ptr == '_')
-	       && !parser_state_tos->p_l_follow
-	       && !parser_state_tos->block_init
-	       && (parser_state_tos->last_token == rparen
-		   || parser_state_tos->last_token == semicolon
-		   || parser_state_tos->last_token == rbrace
-		   || parser_state_tos->last_token == decl
-		   || parser_state_tos->last_token == lbrace
-		   || parser_state_tos->last_token == start_token))
+      else if (((*buf_ptr == '*' && buf_ptr[1] != '=') || isalpha (*buf_ptr) || *buf_ptr == '_')
+	       && !parser_state_tos->p_l_follow && !parser_state_tos->block_init
+	       && (parser_state_tos->last_token == rparen || parser_state_tos->last_token == semicolon
+		   || parser_state_tos->last_token == rbrace || parser_state_tos->last_token == decl
+		   || parser_state_tos->last_token == lbrace || parser_state_tos->last_token == start_token))
 	{
 	  parser_state_tos->its_a_keyword = true;
 	  parser_state_tos->last_u_d = true;
@@ -559,6 +549,14 @@ lexi ()
   if (++buf_ptr >= buf_end)
     fill_buffer ();
 
+  /* If it is a backslash new-line, just eat the backslash */
+  if (*token == '\\' && buf_ptr[0] == EOL)
+    {
+      token = buf_ptr;
+      if (++buf_ptr >= buf_end)
+	fill_buffer ();
+    }
+
   switch (*token)
     {
     case '\0':
@@ -613,9 +611,7 @@ lexi ()
 
       if (*buf_ptr == EOL || *buf_ptr == 0)
 	{
-	  WARNING ((qchar == '\''
-		    ? "Unterminated character constant"
-		    : "Unterminated string constant"), 0, 0);
+	  WARNING ((qchar == '\'' ? "Unterminated character constant" : "Unterminated string constant"), 0, 0);
 	}
       else
 	{
@@ -637,7 +633,7 @@ lexi ()
 
     case ('['):
       if (parser_state_tos->in_or_st)
-        parser_state_tos->in_or_st++;
+	parser_state_tos->in_or_st++;
       unary_delim = true;
       code = lparen;
       break;
@@ -649,7 +645,7 @@ lexi ()
 
     case (']'):
       if (parser_state_tos->in_or_st > 1)
-        parser_state_tos->in_or_st--;
+	parser_state_tos->in_or_st--;
       code = rparen;
       break;
 
@@ -798,8 +794,7 @@ lexi ()
 				   switch */
 
     case '=':
-      if (parser_state_tos->in_or_st &&
-	  parser_state_tos->last_token != cpp_operator)
+      if (parser_state_tos->in_or_st && parser_state_tos->last_token != cpp_operator)
 	{
 	  parser_state_tos->block_init = 1;
 	  parser_state_tos->block_init_level = 0;
@@ -807,8 +802,7 @@ lexi ()
 
       if (*buf_ptr == '=')	/* == */
 	buf_ptr++;
-      else if (*buf_ptr == '-'
-	       || *buf_ptr == '+' || *buf_ptr == '*' || *buf_ptr == '&')
+      else if (*buf_ptr == '-' || *buf_ptr == '+' || *buf_ptr == '*' || *buf_ptr == '&')
 	{
 	  /* Something like x=-1, which can mean x -= 1 ("old style" in K&R1)
 	     or x = -1 (ANSI).  Note that this is only an ambiguity if the
@@ -817,10 +811,8 @@ lexi ()
 	     people want to detect and eliminate old style assignments but
 	     they don't want indent to silently change the meaning of their
 	     code).  */
-	  WARNING
-	    ("old style assignment ambiguity in \"=%c\".  Assuming \"= %c\"\n",
-	     (unsigned int *) (int) *buf_ptr,
-	     (unsigned int *) (int) *buf_ptr);
+	  WARNING ("old style assignment ambiguity in \"=%c\".  Assuming \"= %c\"\n",
+		   (unsigned long) *((unsigned char *) buf_ptr), (unsigned long) *((unsigned char *) buf_ptr));
 	}
 
       code = binary_op;
@@ -837,8 +829,7 @@ lexi ()
          one token, but I don't think that will cause any harm.  */
       /* in C++ mode also scan <?[=], >?[=] GNU C++ operators 
          maybe some flag to them ? */
-      while (*buf_ptr == '>' || *buf_ptr == '<' || *buf_ptr == '=' ||
-             (c_plus_plus && *buf_ptr == '?') ) 
+      while (*buf_ptr == '>' || *buf_ptr == '<' || *buf_ptr == '=' || (c_plus_plus && *buf_ptr == '?'))
 	{
 	  if (++buf_ptr >= buf_end)
 	    fill_buffer ();
@@ -871,6 +862,7 @@ lexi ()
 	    {
 	      /* Threat comments of type / *UPPERCASE* / not as comments */
 	      char *p = buf_ptr;
+
 	      while (isupper (*p++));	/* There is always at least one
 					   newline in the buffer; so no
 					   need to check for buf_end. */
@@ -931,8 +923,8 @@ addkey (key, val)
   struct templ *p;
 
   /* Check to see whether key is a reserved word or not. */
-  if ( (c_plus_plus  && is_reserved_cc (key, strlen (key)) != 0) ||
-       (!c_plus_plus && is_reserved    (key, strlen (key)) != 0) )
+  if ((c_plus_plus && is_reserved_cc (key, strlen (key)) != 0)
+      || (!c_plus_plus && is_reserved (key, strlen (key)) != 0))
     return;
 
   if (user_specials == 0)
@@ -944,9 +936,7 @@ addkey (key, val)
   else if (user_specials_idx == user_specials_max)
     {
       user_specials_max += 5;
-      user_specials = (struct templ *) xrealloc ((char *) user_specials,
-						 user_specials_max *
-						 sizeof (struct templ));
+      user_specials = (struct templ *) xrealloc ((char *) user_specials, user_specials_max * sizeof (struct templ));
     }
 
   p = &user_specials[user_specials_idx++];
